@@ -68,4 +68,4 @@ from .topng import topng
 def instagram(ctx, inputfile, outputfile, dpi, transparent, ranges, pages):
     ctx.invoke(topng, inputfile=inputfile, ranges=ranges)
     for i in range(ranges[0], ranges[1]+1):
-        ctx.invoke(blur, inputfile=f'main-{i}.png', outputfile=f'main-{i}b.png', opacity=0.35, radius=2)
+        ctx.invoke(blur, inputimage=f'main-{i}.png', outputimage=f'main-{i}b.png', opacity=0.35, radius=2)
